@@ -7,14 +7,20 @@ gameR_colors <- list(
   cups = c("#df4418", "#63a0bf", "#ffcf10", "#a6da38", "#7b6aa1"),
   cyberpunk = c("#faf22b", "#49aeec", "#ff193b", "#000000"),
   fallout = c("#0068b1", "#fff874", "#27f286"),
+  frisk = c("#3d120e", "#ffc90e", "#67a4e0", "#e607f8", "#000000"),
   gris = c("#256484", "#e493a3", "#efa225", "#4a938e"),
+  human_rev = c("#fff69f", "#fdd870", "#d0902f", "#a15501", "#351409"),
   kirby = c("#ffa8dc", "#c21f24", "#4fd644"),
+  new_horizon = c("#9dffb0", "#81f1f7", "#fffffa", "#c48d3f", "#fff563"),
   ocarina = c("#02940a", "#4f4499", "#e2e844", "#e94117"),
   okami = c("#56735a", "#f27934", "#c8e7e3", "#e2afb3", "#bfb582"),
   p3r = c("#00a9f0", "#0768c0", "#e01d2f", "#000116", "#7bbf34"),
   p4g = c("#ffe52c", "#7fe6ef", "#faa622", "#c4d70c", "#c22303"),
+  papyrus = c("#ffffff", "#393852", "#4782c9", "#ff4711", "#ffe467"),
   pman = c("#fffd54", "#e93423", "#5acafa", "#f3aa3c", "#f2acda"),
+  radio = c("#70B544", "#085E3B", "#7B3CB8", "#DDD901", "#1A252B"),
   rayman = c("#945682", "#fcb24c", "#be3b45"),
+  sans = c("#ffffff", "#393852", "#4782c9", "#c8c2e2", "#000000"),
   sonic = c("#4040e0", "#c00000", "#e0e000", "#42a606"),
   spirit = c("#8fe7fa", "#b41d1f", "#55964b", "#e9bf4c"),
   splat = c("#F02D7D", "#19D719", "#fffa2f", "#0132fa"),
